@@ -1,5 +1,5 @@
 import numpy as np
-import vg
+from vg.compat import v2 as vg
 from .validation import check_arity
 
 
